@@ -10,8 +10,17 @@ use Giovanni::Stages;
 
 extends 'Giovanni::Stages';
 
+=head1 NAME
 
-our $VERSION = '1.9';
+Giovanni - a Perl based deployment system
+
+=head1 VERSION
+
+Version 1.2.1.0
+
+=cut
+
+our $VERSION = '1.2';
 
 has 'debug' => (
     is        => 'rw',
@@ -74,6 +83,26 @@ has 'notifyer' => (
     default => 'jabber',
 );
 
+=head1 SYNOPSIS
+
+Giovanni is a Perl replacement for the idea behind Capistrano. It is a
+deployment system that can be used comfortably from the commandline to
+check out code, restart systems and notify.
+The system is currently used with git and manages some Catalyst and
+Mojolicious apps and notifies via Jabber. It supports timestamped
+rollouts (ie have the last 5 versions of your code on the server and link
+to the currently running one) and plain git repositories. It tries to
+detect problems in the deployment process and rolls back. It supports
+manual rollbacks, two restart modes and does all that without any code
+on the server. All you need is a working ssh setup with ssh-keys that
+handle the login. 
+We also use it with Jenkins to automatically deploy
+code that successfully completed the test suite.
+
+Giovanni comes with a commandline tool called gio. Check the gio manpage
+for the config file format.
+
+=cut
 
 sub deploy {
     my ($self) = @_;
@@ -85,6 +114,7 @@ sub deploy {
     $self->process_stages($ssh, 'deploy');
 }
 
+
 sub rollback {
     my ($self, $offset) = @_;
 
@@ -95,22 +125,15 @@ sub rollback {
 sub process_stages {
     my ($self, $ssh, $mode) = @_;
 
-    my $conf_key = ($mode eq 'restart' ? 'deploy' : $mode);
-    my @stages = split(/\s*,\s*/, $self->config->{$conf_key});
+    my @stages = split(/\s*,\s*/, $self->config->{$mode});
     foreach my $stage (@stages) {
-        if($mode eq 'restart'){
-            next unless $stage =~ m/restart/;
-            $self->process_hosts($ssh, $stage, $mode);
+        $self->process_hosts($ssh, $stage, $mode);
 
-        } else {
-            $self->process_hosts($ssh, $stage, $mode);
-
-            # if one host produced an error while restarting, rollback all
-            if ($self->error and ($stage =~ m/^restart/i) and ($mode eq 'deploy')) {
-                $self->log('ERROR', $self->error);
-                $self->process_stages($ssh, 'rollback');
-                return;
-            }
+        # if one host produced an error while restarting, rollback all
+        if ($self->error and ($stage =~ m/^restart/i) and ($mode eq 'deploy')) {
+            $self->log('ERROR', $self->error);
+            $self->process_stages($ssh, 'rollback');
+            return;
         }
     }
 }
@@ -146,10 +169,6 @@ sub _get_ssh_conn {
 }
 
 sub restart {
-    my ($self) = @_;
-
-    my $ssh = $self->_get_ssh_conn;
-    $self->process_stages($ssh, 'restart');
 }
 
 sub load_plugin {
@@ -182,7 +201,6 @@ sub log {
 
 sub notify {
     my ($self, $ssh, $conf) = @_;
-
     # load notify plugin
     $self->load_plugin($self->notifyer);
     $self->send_notify($ssh, $conf);
@@ -190,49 +208,6 @@ sub notify {
 }
 
 
-1;
-
-__END__
-
-=pod
-
-=encoding UTF-8
-
-=head1 NAME
-
-Giovanni
-
-=head1 VERSION
-
-version 1.12
-
-=head1 SYNOPSIS
-
-Giovanni is a Perl replacement for the idea behind Capistrano. It is a
-deployment system that can be used comfortably from the commandline to
-check out code, restart systems and notify.
-The system is currently used with git and manages some Catalyst and
-Mojolicious apps and notifies via Jabber. It supports timestamped
-rollouts (ie have the last 5 versions of your code on the server and link
-to the currently running one) and plain git repositories. It tries to
-detect problems in the deployment process and rolls back. It supports
-manual rollbacks, two restart modes and does all that without any code
-on the server. All you need is a working ssh setup with ssh-keys that
-handle the login. 
-We also use it with Jenkins to automatically deploy
-code that successfully completed the test suite.
-
-Giovanni comes with a commandline tool called gio. Check the gio manpage
-for the config file format.
-
-=head1 NAME
-
-Giovanni - a Perl based deployment system
-
-=head1 VERSION
-
-Version 1.9
-
 =head1 AUTHOR
 
 Lenz Gschwendtner, C<< <norbu09 at cpan.org> >>
@@ -243,12 +218,16 @@ Please report any bugs or feature requests to C<bug-giovanni at rt.cpan.org>, or
 the web interface at L<http://rt.cpan.org/NoAuth/ReportBug.html?Queue=Giovanni>.  I will be notified, and then you'll
 automatically be notified of progress on your bug as I make changes.
 
+
+
+
 =head1 SUPPORT
 
 You can find documentation for this module with the perldoc command.
 
     perldoc Giovanni
 
+
 You can also look for information at:
 
 =over 4
@@ -271,8 +250,10 @@ L<http://search.cpan.org/dist/Giovanni/>
 
 =back
 
+
 =head1 ACKNOWLEDGEMENTS
 
+
 =head1 LICENSE AND COPYRIGHT
 
 Copyright 2011 Lenz Gschwendtner.
@@ -283,15 +264,7 @@ by the Free Software Foundation; or the Artistic License.
 
 See http://dev.perl.org/licenses/ for more information.
 
-=head1 AUTHOR
-
-Lenz Gschwendtner <mail@norbu09.org>
-
-=head1 COPYRIGHT AND LICENSE
-
-This software is copyright (c) 2014 by ideegeo Group Limited.
-
-This is free software; you can redistribute it and/or modify it under
-the same terms as the Perl 5 programming language system itself.
 
 =cut
+
+1;
